{% extends "site_base.html" %}
{% load i18n %}
{% load url from future %}

{% block title %} {{ block.super }} {% endblock %}

{% block body_class %}documents{% endblock %}

{% block body_outer %}
    <div class="span12">
      <ul class="nav nav-tabs" id="subnav-tabs">
            <li><a href="{% url "documents_browse" %}" class="explore">{% trans "Documents" %}</a></li>
            <li><a href="{% url "document_upload" %}" class="upload">{% trans "Upload Documents" %}</a></li>
      </ul>
    </div>
    {% block body %}{% endblock body %}
    {% block sidebar %}{% endblock sidebar %}
{% endblock body_outer %}