{% extends "site_base.html" %}
{% load i18n %}
{% load url from future %}

{% block title %} {{ block.super }} {% endblock %}

{% block body_class %}people{% endblock %}

{% block body_outer %}
  <div class="span12">
    <ul class="nav nav-tabs" id="subnav-tabs">
      <li><a href="{% url "profile_browse" %}" class="explore">{% trans "People" %}</a></li>
    </ul>
  </div>
  {% block body %}{% endblock body %}
  {% block sidebar %}{% endblock sidebar %}
{% endblock body_outer %}