{% load i18n %}

<div ng-app="geogitApp" ng-controller="DiffController">
	<div ng-controller="HistoryController" id="geogitHistory" class="geogitHistory">
		<input class="geogit-history-query" ng-model="query" placeholder="Search through history" />
		<ul class="geogit-history unstyled wide">
			<li class="geogit-commit-history" ng-repeat="commit in history | filter:query" 
				style="margin-bottom:15px;border-bottom:1px solid black;">
				<p class="commit-id" geogit-commit-id="{[{commit.id}]}"><strong>commit:</strong> {[{commit.id}]}</p>
				<p class="commit-author"><strong>author:</strong> {[{commit.author.name}]}</p>
				<p class="commit-email"><strong>email:</strong> {[{commit.author.email}]}</p>
				<p class="commit-date"><strong>date:</strong> {[{getDate(commit.author.timestamp)}]}</p>
				<p class="commit-time"><strong>time:</strong> {[{getTime(commit.author.timestamp)}]}</p>
				<p class="commit-message"><strong>message:</strong> {[{commit.message}]}</p>
			</li>
		</ul>
	</div>
	<div ng-controller="CommitController" id="geogitCommit" class="geogitCommit">
		<a class="back-to-history">Back to history</a>
		<input class="geogit-history-query" ng-model="query" placeholder="Search through features" />
		<ul class="geogit-history">
			<li class="geogit-commit" feature-id="{[{ diff.newObjectId }]}" ng-repeat="diff in diffs | filter:query">
				<p class="commit-id">featureId: {[{diff.newObjectId}]}</p>
				<p class="commit-date">changeType: {[{diff.changeType}]}</p>
			</li>
		</ul>
	</div>
</div>
