<!-- OpenLayers resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/openlayers/theme/default/style.css">
<!-- Lightbox resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/lightbox/css/lightbox.css">
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/lightbox/css/screen.css">
<script type="text/javascript" src="{{ STATIC_URL }}geoexplorer/externals/lightbox/js/jquery-1.7.2.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}geoexplorer/externals/lightbox/js/lightbox.js"></script>
<!-- GeoExt resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/geoext/resources/css/popup.css">
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/geoext/resources/css/layerlegend.css">
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/geoext/resources/css/gxtheme-gray.css">
<!-- gxp resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}geoexplorer/externals/gxp/src/theme/all.css">
<!-- ux resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}sdk/theme/ux/colorpicker/color-picker.ux.css" >
<!-- GeoNode mixin -->
<script type="text/javascript" src="{{ STATIC_URL}}geonode/js/extjs/GeoNode-mixin.js"></script>
<!-- app resources -->
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}sdk/theme/app/style.css">
<script type="text/javascript" src="{{ STATIC_URL }}sdk/lib/app.js"></script>
<script type="text/javascript">
OpenLayers.ImgPath = "{{ STATIC_URL }}sdk/externals/openlayers/img/";
OpenLayers.Request.DEFAULT_CONFIG.headers = {
    'X-CSRFToken': '{{ csrf_token|escapejs }}'
};
</script>
